@@ -4,12 +4,16 @@ module System.Log.FastLogger.Internal
   ( module System.Log.FastLogger.IO
   , module System.Log.FastLogger.FileIO
   , module System.Log.FastLogger.LogStr
-  , module System.Log.FastLogger.Logger
+  , module System.Log.FastLogger.SingleLogger
+  , module System.Log.FastLogger.MultiLogger
+  , module System.Log.FastLogger.Write
   , module System.Log.FastLogger.LoggerSet
   ) where
 
 import System.Log.FastLogger.IO
 import System.Log.FastLogger.FileIO
 import System.Log.FastLogger.LogStr
-import System.Log.FastLogger.Logger
+import System.Log.FastLogger.SingleLogger
+import System.Log.FastLogger.MultiLogger
+import System.Log.FastLogger.Write
 import System.Log.FastLogger.LoggerSet
